@@ -57,11 +57,7 @@ impl Default for Instance {
         let domain = Some(String::new());
         let query = Some(String::new());
 
-        Self {
-            domain,
-            client,
-            query,
-        }
+        Self { domain, client, query }
     }
 }
 
@@ -74,8 +70,8 @@ impl Instance {
         let mut domains = INVIDIOUS_INSTANCE_LIST;
         let mut video_result: Vec<YoutubeVideo> = Vec::new();
         domains.shuffle(&mut rand::thread_rng());
-        for v in &domains {
-            let mut url: String = (*v).to_string();
+        for v in domains {
+            let mut url: String = v.to_string();
             url.push_str("/api/v1/search");
 
             if_chain! {
@@ -85,7 +81,7 @@ impl Instance {
                 if let Some(vr) = Self::parse_youtube_options(&text);
                 then {
                     video_result = vr;
-                    domain = (*v).to_string();
+                    domain = v.to_string();
                     break;
                 }
             }
@@ -139,8 +135,7 @@ impl Instance {
     pub fn get_suggestions(&self, prefix: &str) -> Result<Vec<YoutubeVideo>> {
         // query := url.QueryEscape(prefix)
         // targetUrl :=
-        let mut url =
-            "http://suggestqueries.google.com/complete/search?client=firefox&ds=yt&q=".to_string();
+        let mut url = "http://suggestqueries.google.com/complete/search?client=firefox&ds=yt&q=".to_string();
         url.push_str(prefix);
 
         let result = self.client.get(&url).call()?;
@@ -151,20 +146,6 @@ impl Instance {
             },
             _ => bail!("Error during search"),
         }
-
-        // res := []json.RawMessage{}
-        // err := getRequest(targetUrl, &res)
-        // if err != nil {
-        // 	return nil, tracerr.Wrap(err)
-        // }
-
-        // suggestions := []string{}
-        // err = json.Unmarshal(res[1], &suggestions)
-        // if err != nil {
-        // 	return nil, tracerr.Wrap(err)
-        // }
-
-        // return suggestions, nil
     }
 
     // GetTrendingMusic fetch music trending based on region.
