@@ -51,25 +51,25 @@ fn main() {
 
     args.remove(0);
     let mut should_exit = false;
-    for i in args.clone() {
+    for i in args {
         let i = i.as_str();
         match i {
-            "-v" => {
+            "-v" | "--version" => {
                 println!("Termusic version is: {}", VERSION);
                 should_exit = true;
-            }
+            },
 
-            "-h" => {
+            "-h" | "--help" => {
                 println!(
                     r"Termusic help:
 Usage: termusic [DIRECTORY] [OPTIONS]
--v print version and exit.
--h print this message and exit.
+-v or --version print version and exit.
+-h or --help print this message and exit.
 directory: start termusic with directory.
 no arguments: start termusic with ~/.config/termusic/config.toml"
                 );
                 should_exit = true;
-            }
+            },
 
             _ => {
                 let p = Path::new(i);
@@ -91,14 +91,14 @@ no arguments: start termusic with ~/.config/termusic/config.toml"
                         r"Unknown arguments
 Termusic help:
 Usage: termusic [DIRECTORY] [OPTIONS]
--v print version and exit.
--h print this message and exit.
+-v or --version print version and exit.
+-h or --help print this message and exit.
 directory: start termusic with directory.
 no arguments: start termusic with ~/.config/termusic/config.toml"
                     );
                     should_exit = true;
                 }
-            }
+            },
         }
     }
 
