@@ -33,9 +33,7 @@ use gstreamer_player as gst_player;
 #[cfg(feature = "mpris")]
 use crate::song::Song;
 #[cfg(feature = "mpris")]
-use crate::souvlaki::{
-    MediaControlEvent, MediaControls, MediaMetadata, MediaPlayback, PlatformConfig,
-};
+use crate::souvlaki::{MediaControlEvent, MediaControls, MediaMetadata, MediaPlayback, PlatformConfig};
 #[cfg(feature = "mpris")]
 use std::str::FromStr;
 #[cfg(feature = "mpris")]
@@ -49,7 +47,6 @@ pub struct GStreamer {
     controls: MediaControls,
     #[cfg(feature = "mpris")]
     pub rx: Receiver<MediaControlEvent>,
-    // mpris: Arc<Mpris>,
 }
 
 // unsafe impl Send for GSTPlayer {}
@@ -59,10 +56,7 @@ impl GStreamer {
     pub fn new() -> Self {
         gst::init().expect("Couldn't initialize Gstreamer");
         let dispatcher = gst_player::PlayerGMainContextSignalDispatcher::new(None);
-        let player = gst_player::Player::new(
-            None,
-            Some(&dispatcher.upcast::<gst_player::PlayerSignalDispatcher>()),
-        );
+        let player = gst_player::Player::new(None, Some(&dispatcher.upcast::<gst_player::PlayerSignalDispatcher>()));
 
         #[cfg(feature = "mpris")]
         let config = PlatformConfig {
@@ -91,7 +85,6 @@ impl GStreamer {
             controls,
             #[cfg(feature = "mpris")]
             rx,
-            // mpris,
         }
     }
 
