@@ -23,7 +23,7 @@
  */
 mod model;
 
-use super::netease::encrypt::Crypto;
+use super::encrypt::Crypto;
 use anyhow::{anyhow, bail, Result};
 use model::{to_lyric, to_lyric_id_accesskey, to_pic_url, to_song_info, to_song_url};
 // use std::io::Write;
@@ -36,24 +36,18 @@ static URL_LYRIC_SEARCH_KUGOU: &str = "http://krcs.kugou.com/search";
 static URL_LYRIC_DOWNLOAD_KUGOU: &str = "http://lyrics.kugou.com/download";
 static URL_SONG_DOWNLOAD_KUGOU: &str = "http://www.kugou.com/yy/index.php?r=play/getdata";
 
-pub struct KugouApi {
+pub struct Api {
     client: Agent,
 }
 
-impl KugouApi {
+impl Api {
     pub fn new() -> Self {
         let client = AgentBuilder::new().timeout(Duration::from_secs(10)).build();
 
         Self { client }
     }
 
-    pub fn search(
-        &mut self,
-        keywords: &str,
-        types: u32,
-        offset: u16,
-        limit: u16,
-    ) -> Result<String> {
+    pub fn search(&self, keywords: &str, types: u32, offset: u16, limit: u16) -> Result<String> {
         let result = self
             .client
             .post(URL_SEARCH_KUGOU)
@@ -75,14 +69,14 @@ impl KugouApi {
                 let song_info = to_song_info(&result).ok_or_else(|| anyhow!("Search Error"))?;
                 let song_info_string = serde_json::to_string(&song_info)?;
                 Ok(song_info_string)
-            }
+            },
             _ => bail!("None Error"),
         }
     }
 
     // search and download lyrics
     // music_id: 歌曲id
-    pub fn song_lyric(&mut self, music_id: &str) -> Result<String> {
+    pub fn song_lyric(&self, music_id: &str) -> Result<String> {
         let result = self
             .client
             .get(URL_LYRIC_SEARCH_KUGOU)
@@ -94,8 +88,7 @@ impl KugouApi {
             .call()?
             .into_string()?;
 
-        let (accesskey, id) =
-            to_lyric_id_accesskey(&result).ok_or_else(|| anyhow!("Search Error"))?;
+        let (accesskey, id) = to_lyric_id_accesskey(&result).ok_or_else(|| anyhow!("Search Error"))?;
 
         let result = self
             .client
@@ -114,7 +107,7 @@ impl KugouApi {
 
     // 歌曲 URL
     // ids: 歌曲列表
-    pub fn song_url(&mut self, id: &str, album_id: &str) -> Result<String> {
+    pub fn song_url(&self, id: &str, album_id: &str) -> Result<String> {
         let kg_mid = Crypto::alpha_lowercase_random_bytes(32);
         let result = self
             .client
@@ -132,7 +125,7 @@ impl KugouApi {
     }
 
     // download picture
-    pub fn pic(&mut self, id: &str, album_id: &str) -> Result<Vec<u8>> {
+    pub fn pic(&self, id: &str, album_id: &str) -> Result<Vec<u8>> {
         let kg_mid = Crypto::alpha_lowercase_random_bytes(32);
         let result = self
             .client
