@@ -80,7 +80,7 @@ impl Api {
     ) -> Result<String> {
         let mut url = format!("{}{}", BASE_URL_NETEASE, path);
         match method {
-            Method::POST => {
+            Method::Post => {
                 let user_agent = match cryptoapi {
                     CryptoApi::Linuxapi => LINUX_USER_AGNET.to_string(),
                     CryptoApi::Weapi => choose_user_agent(ua).to_string(),
@@ -95,13 +95,13 @@ impl Api {
                         );
                         url = "https://music.163.com/api/linux/forward".to_owned();
                         Crypto::linuxapi(&data)
-                    }
+                    },
                     CryptoApi::Weapi => {
                         let mut params = params;
                         params.insert("csrf_token", &self.csrf[..]);
                         let text = serde_json::to_string(&params)?;
                         Crypto::weapi(&text)
-                    }
+                    },
                 };
 
                 let response = self
@@ -123,20 +123,17 @@ impl Api {
                     let value = response.header("set-cookie");
                     if let Some(v) = value {
                         if v.contains("__csrf") {
-                            let csrf_token =
-                                _CSRF
-                                    .captures(v)
-                                    .map_or("", |caps| match caps.name("csrf") {
-                                        Some(c) => c.as_str(),
-                                        None => "",
-                                    });
+                            let csrf_token = _CSRF.captures(v).map_or("", |caps| match caps.name("csrf") {
+                                Some(c) => c.as_str(),
+                                None => "",
+                            });
                             self.csrf = csrf_token.to_owned();
                         }
                     }
                 }
                 Ok(response.into_string()?)
-            }
-            Method::GET => Ok(self.client.get(&url).call()?.into_string()?),
+            },
+            Method::Get => Ok(self.client.get(&url).call()?.into_string()?),
         }
     }
 
@@ -146,13 +143,7 @@ impl Api {
     // offset: 起始点
     // limit: 数量
     #[allow(unused)]
-    pub fn search(
-        &mut self,
-        keywords: &str,
-        types: u32,
-        offset: u16,
-        limit: u16,
-    ) -> Result<String> {
+    pub fn search(&mut self, keywords: &str, types: u32, offset: u16, limit: u16) -> Result<String> {
         let path = "/weapi/search/get";
         let mut params = HashMap::new();
         let types_str = &types.to_string();
@@ -162,18 +153,17 @@ impl Api {
         params.insert("type", types_str);
         params.insert("offset", offset);
         params.insert("limit", limit);
-        let result = self.request(Method::POST, path, params, CryptoApi::Weapi, "")?;
+        let result = self.request(Method::Post, path, params, CryptoApi::Weapi, "")?;
 
         // let mut file = std::fs::File::create("data.txt").expect("create failed");
         // file.write_all(result.as_bytes()).expect("write failed");
 
         match types {
             1 => {
-                let songtag_vec =
-                    to_song_info(&result, Parse::SEARCH).ok_or_else(|| anyhow!("Search Error"))?;
+                let songtag_vec = to_song_info(&result, Parse::Search).ok_or_else(|| anyhow!("Search Error"))?;
                 let songtag_string = serde_json::to_string(&songtag_vec)?;
                 Ok(songtag_string)
-            }
+            },
             _ => bail!("None Error"),
         }
     }
@@ -189,7 +179,7 @@ impl Api {
         params.insert("lv", "-1");
         params.insert("tv", "-1");
         params.insert("csrf_token", &csrf_token);
-        let result = self.request(Method::POST, path, params, CryptoApi::Weapi, "")?;
+        let result = self.request(Method::Post, path, params, CryptoApi::Weapi, "")?;
         to_lyric(&result).ok_or_else(|| anyhow!("Search Error"))
     }
 
@@ -205,7 +195,7 @@ impl Api {
         params.insert("level", "standard");
         params.insert("encodeType", "aac");
         params.insert("csrf_token", &csrf_token);
-        let result = self.request(Method::POST, path, params, CryptoApi::Weapi, "")?;
+        let result = self.request(Method::Post, path, params, CryptoApi::Weapi, "")?;
         to_song_url(&result).ok_or_else(|| anyhow!("Search Error"))
     }
 
