@@ -40,12 +40,7 @@ pub fn to_singer_info(json: &str) -> Option<Vec<SingerInfo>> {
                 vec.push(SingerInfo {
                     id: v.get("id")?.as_u64()?,
                     name: v.get("name")?.as_str()?.to_owned(),
-                    pic_url: v
-                        .get("picUrl")
-                        .unwrap_or(&json!(""))
-                        .as_str()
-                        .unwrap_or("")
-                        .to_owned(),
+                    pic_url: v.get("picUrl").unwrap_or(&json!("")).as_str().unwrap_or("").to_owned(),
                 });
             }
             return Some(vec);
@@ -71,12 +66,7 @@ pub fn to_song_url(json: &str) -> Option<Vec<SongUrl>> {
             let mut vec: Vec<SongUrl> = Vec::new();
             let array = value.get("data")?.as_array()?;
             for v in array.iter() {
-                let url = v
-                    .get("url")
-                    .unwrap_or(&json!(""))
-                    .as_str()
-                    .unwrap_or("")
-                    .to_owned();
+                let url = v.get("url").unwrap_or(&json!("")).as_str().unwrap_or("").to_owned();
                 if !url.is_empty() {
                     vec.push(SongUrl {
                         id: v.get("id")?.as_u64()?,
@@ -110,34 +100,16 @@ pub struct SongInfo {
     pub song_url: String,
 }
 
-impl SongInfo {
-    // pub fn get_song_cache_path(&self) -> PathBuf {
-    //     PathBuf::from(
-    //         format!(
-    //             "{}{}-{}.m4a",
-    //             NCM_CACHE.to_string_lossy(),
-    //             self.name,
-    //             self.id
-    //         )
-    //         .as_str(),
-    //     )
-    // }
-}
-
 // parse: 解析方式
 pub fn to_song_info(json: &str, parse: Parse) -> Option<Vec<SongTag>> {
     if let Ok(value) = serde_json::from_str::<Value>(json) {
         if value.get("code")?.eq(&200) {
             let mut vec: Vec<SongInfo> = Vec::new();
-            if let Parse::SEARCH = parse {
+            if let Parse::Search = parse {
                 let array = value.get("result")?.as_object()?.get("songs")?.as_array()?;
                 for v in array.iter() {
                     let duration = v.get("duration")?.as_u64()?;
-                    let pic_id = v
-                        .get("album")?
-                        .get("picId")
-                        .unwrap_or(&json!("Unknown"))
-                        .as_u64()?;
+                    let pic_id = v.get("album")?.get("picId").unwrap_or(&json!("Unknown")).as_u64()?;
                     let fee = v.get("fee")?.as_u64()?;
                     let url = if fee == 0 {
                         "Downloadable".to_string()
@@ -163,11 +135,7 @@ pub fn to_song_info(json: &str, parse: Parse) -> Option<Vec<SongTag>> {
                             .unwrap_or("Unknown Album")
                             .to_owned(),
                         pic_url: pic_id.to_string(),
-                        duration: format!(
-                            "{:0>2}:{:0>2}",
-                            duration / 1000 / 60,
-                            duration / 1000 % 60
-                        ),
+                        duration: format!("{:0>2}:{:0>2}", duration / 1000 / 60, duration / 1000 % 60),
                         song_url: url,
                     });
                 }
@@ -205,28 +173,6 @@ pub struct SongList {
     pub cover_img_url: String,
 }
 
-// // 消息
-// #[derive(Debug, Deserialize, Serialize)]
-// pub struct Msg {
-//     pub code: i64,
-//     pub msg: String,
-// }
-
-// pub fn to_msg(json: &str) -> Option<Msg> {
-//     if let Ok(value) = serde_json::from_str::<Value>(json) {
-//         let code = value.get("code")?.as_i64()?;
-//         if code.eq(&200) {
-//             return Some(Msg {
-//                 code: 200,
-//                 msg: "".to_owned(),
-//             });
-//         }
-//         let msg = value.get("msg")?.as_str()?.to_owned();
-//         return Some(Msg { code, msg });
-//     }
-//     None
-// }
-
 // 登陆信息
 #[derive(Debug, Clone, Deserialize, Serialize)]
 pub struct LoginInfo {
@@ -242,38 +188,12 @@ pub struct LoginInfo {
     pub msg: String,
 }
 
-// #[allow(unused, clippy::cast_possible_truncation)]
-// pub fn to_login_info(json: &str) -> Option<LoginInfo> {
-//     if let Ok(value) = serde_json::from_str::<Value>(json) {
-//         let code = value.get("code")?.as_i64()? as i32;
-//         if code.eq(&200) {
-//             let profile = value.get("profile")?.as_object()?;
-//             return Some(LoginInfo {
-//                 code,
-//                 uid: profile.get("userId")?.as_u64()?,
-//                 nickname: profile.get("nickname")?.as_str()?.to_owned(),
-//                 avatar_url: profile.get("avatarUrl")?.as_str()?.to_owned(),
-//                 msg: "".to_owned(),
-//             });
-//         }
-//         let msg = value.get("msg")?.as_str()?.to_owned();
-//         return Some(LoginInfo {
-//             code,
-//             uid: 0,
-//             nickname: "".to_owned(),
-//             avatar_url: "".to_owned(),
-//             msg,
-//         });
-//     }
-//     None
-// }
-
 // 请求方式
-#[allow(unused, clippy::upper_case_acronyms)]
+#[allow(unused)]
 #[derive(Clone, Copy, Debug)]
 pub enum Method {
-    POST,
-    GET,
+    Post,
+    Get,
 }
 
 // 解析方式
@@ -285,9 +205,9 @@ pub enum Method {
 // SD: 单曲详情
 // ALBUM: 专辑
 // TOP: 热门
-#[allow(unused, clippy::upper_case_acronyms)]
+#[allow(unused)]
 #[derive(Debug, Clone, Copy)]
 pub enum Parse {
-    SEARCH,
-    USL,
+    Search,
+    Usl,
 }
