@@ -1,4 +1,3 @@
-use crate::ui::activity::main::{Status, TermusicActivity};
 use dbus::arg::{RefArg, Variant};
 use dbus::blocking::Connection;
 use dbus::channel::MatchingReceiver;
@@ -74,7 +73,8 @@ pub enum MediaControlEvent {
     /// Open the URI in the media player.
     OpenUri(String),
 
-    /// Bring the media player's user interface to the front using any appropriate mechanism available.
+    /// Bring the media player's user interface to the front using any appropriate mechanism
+    /// available.
     Raise,
     /// Shut down the media player.
     Quit,
@@ -235,8 +235,7 @@ fn mpris_run(
         let event_handler = event_handler.clone();
 
         move |b| {
-            b.property("Identity")
-                .get(move |_, _| Ok(friendly_name.clone()));
+            b.property("Identity").get(move |_, _| Ok(friendly_name.clone()));
 
             register_method(b, &event_handler, "Raise", MediaControlEvent::Raise);
             register_method(b, &event_handler, "Quit", MediaControlEvent::Quit);
@@ -245,10 +244,8 @@ fn mpris_run(
             b.property("CanQuit").get(|_, _| Ok(true));
             b.property("CanRaise").get(|_, _| Ok(true));
             b.property("HasTracklist").get(|_, _| Ok(false));
-            b.property("SupportedUriSchemes")
-                .get(move |_, _| Ok(&[] as &[String]));
-            b.property("SupportedMimeTypes")
-                .get(move |_, _| Ok(&[] as &[String]));
+            b.property("SupportedUriSchemes").get(move |_, _| Ok(&[] as &[String]));
+            b.property("SupportedMimeTypes").get(move |_, _| Ok(&[] as &[String]));
         }
     });
 
@@ -348,14 +345,6 @@ fn mpris_run(
             "PropertiesChanged",
             ("org.freedesktop.DBus.Properties", "Metadata", "Metadata"),
         );
-        // b.signal::<(String, dbus::arg::PropMap, Vec<String>), _>(
-        //     "PropertiesChanged",
-        //     (
-        //         "org.freedesktop.DBus.Properties",
-        //         "PlaybackStatus",
-        //         "PlaybackStatus",
-        //     ),
-        // );
 
         register_method(b, &event_handler, "Play", MediaControlEvent::Play);
         register_method(b, &event_handler, "Pause", MediaControlEvent::Pause);
@@ -414,9 +403,9 @@ fn mpris_run(
 
                 let position: u64 = position.try_into().unwrap();
 
-                (event_handler.lock().unwrap())(MediaControlEvent::SetPosition(MediaPosition(
-                    Duration::from_micros(position),
-                )));
+                (event_handler.lock().unwrap())(MediaControlEvent::SetPosition(MediaPosition(Duration::from_micros(
+                    position,
+                ))));
                 Ok(())
             }
         });
@@ -454,7 +443,7 @@ fn mpris_run(
         }
 
         // Do the event processing.
-        c.process(Duration::from_millis(1000))?;
+        c.process(Duration::from_millis(100))?;
 
         // send propertieschanged signal when received update signal
         if let Ok(()) = update_signal.try_recv() {
@@ -465,24 +454,20 @@ fn mpris_run(
 
             let data = shared_data.lock().unwrap();
             let metadata = data.metadata.clone();
-            changed.changed_properties.insert(
-                "Metadata".to_string(),
-                Variant(Box::new(get_metadata(metadata))),
-            );
+            changed
+                .changed_properties
+                .insert("Metadata".to_string(), Variant(Box::new(get_metadata(metadata))));
             let status = match data.playback_status {
                 MediaPlayback::Playing { .. } => "Playing",
                 MediaPlayback::Paused { .. } => "Paused",
                 MediaPlayback::Stopped => "Stopped",
             };
-            changed.changed_properties.insert(
-                "PlaybackStatus".to_string(),
-                Variant(Box::new(status.to_string())),
-            );
+            changed
+                .changed_properties
+                .insert("PlaybackStatus".to_string(), Variant(Box::new(status.to_string())));
 
             c.channel()
-                .send(changed.to_emit_message(
-                    &DbusPath::new("/org/mpris/MediaPlayer2".to_string()).unwrap(),
-                ))
+                .send(changed.to_emit_message(&DbusPath::new("/org/mpris/MediaPlayer2".to_string()).unwrap()))
                 .unwrap();
         }
         // thread::sleep(Duration::from_millis(100));
@@ -519,52 +504,11 @@ fn get_metadata(song: OwnedMetadata) -> Metadata {
     );
     hm.insert(
         "xesam:artist".to_string(),
-        Variant(Box::new(
-            song.artist.unwrap_or_else(|| "Unknown Artist".to_string()),
-        )),
+        Variant(Box::new(song.artist.unwrap_or_else(|| "Unknown Artist".to_string()))),
     );
     hm.insert(
         "xesam:title".to_string(),
-        Variant(Box::new(
-            song.title.unwrap_or_else(|| "Unknown Title".to_string()),
-        )),
+        Variant(Box::new(song.title.unwrap_or_else(|| "Unknown Title".to_string()))),
     );
     hm
 }
-
-pub fn mpris_handler(e: MediaControlEvent, activity: &mut TermusicActivity) {
-    match e {
-        MediaControlEvent::Next => {
-            activity.next_song();
-        }
-        MediaControlEvent::Previous => {
-            activity.previous_song();
-        }
-        MediaControlEvent::Pause => {
-            activity.player.pause();
-        }
-        MediaControlEvent::Toggle => {
-            if activity.player.is_paused() {
-                activity.status = Some(Status::Running);
-                activity.player.resume();
-            } else {
-                activity.status = Some(Status::Paused);
-                activity.player.pause();
-            }
-        }
-        MediaControlEvent::Play => {
-            activity.player.resume();
-        }
-        // MediaControlEvent::Seek(x) => match x {
-        //     SeekDirection::Forward => activity.player.seek(5).ok(),
-        //     SeekDirection::Backward => activity.player.seek(-5).ok(),
-        // },
-        // MediaControlEvent::SetPosition(position) => {
-        //     let _position = position. / 1000;
-        // }
-        MediaControlEvent::OpenUri(uri) => {
-            activity.player.add_and_play(&uri);
-        }
-        _ => {}
-    }
-}
