@@ -25,11 +25,12 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-// Submodules
-// mod actions;
-// mod config;
+#[cfg(feature = "mpris")]
+mod mpris;
+
 mod library;
 mod playlist;
+mod ueberzug;
 mod update;
 mod view;
 mod youtube_options;
@@ -44,8 +45,12 @@ use crossterm::terminal::{disable_raw_mode, enable_raw_mode};
 use log::error;
 use std::collections::VecDeque;
 use std::path::{Path, PathBuf};
+#[cfg(feature = "cover")]
+use std::process::Child;
 use std::str::FromStr;
 use std::sync::mpsc::{self, Receiver, Sender};
+#[cfg(feature = "cover")]
+use std::sync::RwLock;
 use std::thread::sleep;
 use std::time::Duration;
 use tui_realm_treeview::Tree;
@@ -69,7 +74,6 @@ const COMPONENT_TABLE_SEARCH_LIBRARY: &str = "SEARCH_LIBRARY_TABLE";
 const COMPONENT_INPUT_SEARCH_LIBRARY: &str = "SEARCH_LIBRARY_INPUT";
 
 /// ### `ViewLayout`
-///
 
 /// ## `MainActivity`
 ///
@@ -81,11 +85,11 @@ pub struct TermusicActivity {
     redraw: bool,
     path: PathBuf,
     tree: Tree,
-    pub player: GStreamer,
+    player: GStreamer,
     playlist_items: VecDeque<Song>,
     time_pos: u64,
-    pub status: Option<Status>,
-    pub current_song: Option<Song>,
+    status: Option<Status>,
+    current_song: Option<Song>,
     sender: Sender<UpdateComponents>,
     receiver: Receiver<UpdateComponents>,
     yanked_node_id: Option<String>,
@@ -93,6 +97,8 @@ pub struct TermusicActivity {
     youtube_options: YoutubeOptions,
     sender_playlist_items: Sender<VecDeque<Song>>,
     receiver_playlist_items: Receiver<VecDeque<Song>>,
+    #[cfg(feature = "cover")]
+    ueberzug: RwLock<Option<Child>>,
 }
 
 #[derive(Clone, Copy)]
@@ -156,6 +162,8 @@ impl Default for TermusicActivity {
             youtube_options: YoutubeOptions::new(),
             sender_playlist_items: tx2,
             receiver_playlist_items: rx2,
+            #[cfg(feature = "cover")]
+            ueberzug: RwLock::new(None),
         }
     }
 }
@@ -183,17 +191,15 @@ impl TermusicActivity {
                 }
                 self.status = Some(Status::Running);
                 self.next_song();
-            }
-            Some(Status::Running | Status::Paused) => {}
+            },
+            Some(Status::Running | Status::Paused) => {},
             None => self.status = Some(Status::Stopped),
         };
     }
 
     pub fn run_tageditor(&mut self) {
         let mut tageditor: TagEditorActivity = TagEditorActivity::default();
-        if let Some(Payload::One(Value::Str(node_id))) =
-            self.view.get_state(COMPONENT_TREEVIEW_LIBRARY)
-        {
+        if let Some(Payload::One(Value::Str(node_id))) = self.view.get_state(COMPONENT_TREEVIEW_LIBRARY) {
             let p: &Path = Path::new(node_id.as_str());
             if p.is_dir() {
                 self.mount_error("directory doesn't have tag!");
@@ -212,11 +218,11 @@ impl TermusicActivity {
                         error!("Failed to start TagEditorActivity: context is None");
                         return;
                     }
-                }
+                },
                 Err(e) => {
                     self.mount_error(format!("{}", e).as_ref());
                     return;
-                }
+                },
             };
         }
 
@@ -231,7 +237,6 @@ impl TermusicActivity {
                 break;
             }
             if let Some(ExitReason::NeedRefreshPlaylist(file)) = tageditor.will_umount() {
-                // print!("{}", file);
                 self.sync_library(Some(file));
                 self.update_item_delete();
             }
@@ -312,8 +317,8 @@ impl Activity for TermusicActivity {
 
     /// ### `on_destroy`
     ///
-    /// `on_destroy` is the function which cleans up runtime variables and data before terminating the activity.
-    /// This function must be called once before terminating the activity.
+    /// `on_destroy` is the function which cleans up runtime variables and data before terminating
+    /// the activity. This function must be called once before terminating the activity.
     /// This function finally releases the context
     fn on_destroy(&mut self) -> Option<Context> {
         if let Err(err) = self.save_playlist() {
@@ -328,12 +333,10 @@ impl Activity for TermusicActivity {
         }
         self.context.as_ref()?;
         // Clear terminal and return
-        match self.context.take() {
-            Some(mut ctx) => {
-                ctx.clear_screen();
-                Some(ctx)
-            }
-            None => None,
+        if let Some(mut ctx) = self.context.take() {
+            ctx.clear_screen();
+            return Some(ctx);
         }
+        None
     }
 }
